@@ -423,9 +423,9 @@ static int startApp(QCommandLineParser& p)
 
 	//Attach dialog
 #ifdef HAVE_X11
-        if(attach) {
+	if(attach) {
             dlg.setAttribute(Qt::WA_NativeWindow, true);
-            KWindowSystem::setMainWindow(dlg.windowHandle(), (WId)winid);
+            KWindowSystem::setMainWindow(dlg.windowHandle(), WId(winid));
         }
 #endif
         int ret = dlg.exec();
